@@ -14,7 +14,9 @@ pub const GPG_ERR_SOURCE_GPA: gpg_err_source_t = 12;
 pub const GPG_ERR_SOURCE_KLEO: gpg_err_source_t = 13;
 pub const GPG_ERR_SOURCE_G13: gpg_err_source_t = 14;
 pub const GPG_ERR_SOURCE_ASSUAN: gpg_err_source_t = 15;
+pub const GPG_ERR_SOURCE_TPM2D: gpg_err_source_t = 16;
 pub const GPG_ERR_SOURCE_TLS: gpg_err_source_t = 17;
+pub const GPG_ERR_SOURCE_TKD: gpg_err_source_t = 18;
 pub const GPG_ERR_SOURCE_ANY: gpg_err_source_t = 31;
 pub const GPG_ERR_SOURCE_USER_1: gpg_err_source_t = 32;
 pub const GPG_ERR_SOURCE_USER_2: gpg_err_source_t = 33;
@@ -314,6 +316,13 @@ pub const GPG_ERR_TRY_LATER: gpg_err_code_t = 312;
 pub const GPG_ERR_WRONG_NAME: gpg_err_code_t = 313;
 pub const GPG_ERR_NO_AUTH: gpg_err_code_t = 314;
 pub const GPG_ERR_BAD_AUTH: gpg_err_code_t = 315;
+pub const GPG_ERR_NO_KEYBOXD: gpg_err_code_t = 316;
+pub const GPG_ERR_KEYBOXD: gpg_err_code_t = 317;
+pub const GPG_ERR_NO_SERVICE: gpg_err_code_t = 318;
+pub const GPG_ERR_SERVICE: gpg_err_code_t = 319;
+pub const GPG_ERR_BAD_PUK: gpg_err_code_t = 320;
+pub const GPG_ERR_NO_RESET_CODE: gpg_err_code_t = 321;
+pub const GPG_ERR_BAD_RESET_CODE: gpg_err_code_t = 322;
 pub const GPG_ERR_SYSTEM_BUG: gpg_err_code_t = 666;
 pub const GPG_ERR_DNS_UNKNOWN: gpg_err_code_t = 711;
 pub const GPG_ERR_DNS_SECTION: gpg_err_code_t = 712;
@@ -420,6 +429,37 @@ pub const GPG_ERR_USER_13: gpg_err_code_t = 1036;
 pub const GPG_ERR_USER_14: gpg_err_code_t = 1037;
 pub const GPG_ERR_USER_15: gpg_err_code_t = 1038;
 pub const GPG_ERR_USER_16: gpg_err_code_t = 1039;
+pub const GPG_ERR_SQL_OK: gpg_err_code_t = 1500;
+pub const GPG_ERR_SQL_ERROR: gpg_err_code_t = 1501;
+pub const GPG_ERR_SQL_INTERNAL: gpg_err_code_t = 1502;
+pub const GPG_ERR_SQL_PERM: gpg_err_code_t = 1503;
+pub const GPG_ERR_SQL_ABORT: gpg_err_code_t = 1504;
+pub const GPG_ERR_SQL_BUSY: gpg_err_code_t = 1505;
+pub const GPG_ERR_SQL_LOCKED: gpg_err_code_t = 1506;
+pub const GPG_ERR_SQL_NOMEM: gpg_err_code_t = 1507;
+pub const GPG_ERR_SQL_READONLY: gpg_err_code_t = 1508;
+pub const GPG_ERR_SQL_INTERRUPT: gpg_err_code_t = 1509;
+pub const GPG_ERR_SQL_IOERR: gpg_err_code_t = 1510;
+pub const GPG_ERR_SQL_CORRUPT: gpg_err_code_t = 1511;
+pub const GPG_ERR_SQL_NOTFOUND: gpg_err_code_t = 1512;
+pub const GPG_ERR_SQL_FULL: gpg_err_code_t = 1513;
+pub const GPG_ERR_SQL_CANTOPEN: gpg_err_code_t = 1514;
+pub const GPG_ERR_SQL_PROTOCOL: gpg_err_code_t = 1515;
+pub const GPG_ERR_SQL_EMPTY: gpg_err_code_t = 1516;
+pub const GPG_ERR_SQL_SCHEMA: gpg_err_code_t = 1517;
+pub const GPG_ERR_SQL_TOOBIG: gpg_err_code_t = 1518;
+pub const GPG_ERR_SQL_CONSTRAINT: gpg_err_code_t = 1519;
+pub const GPG_ERR_SQL_MISMATCH: gpg_err_code_t = 1520;
+pub const GPG_ERR_SQL_MISUSE: gpg_err_code_t = 1521;
+pub const GPG_ERR_SQL_NOLFS: gpg_err_code_t = 1522;
+pub const GPG_ERR_SQL_AUTH: gpg_err_code_t = 1523;
+pub const GPG_ERR_SQL_FORMAT: gpg_err_code_t = 1524;
+pub const GPG_ERR_SQL_RANGE: gpg_err_code_t = 1525;
+pub const GPG_ERR_SQL_NOTADB: gpg_err_code_t = 1526;
+pub const GPG_ERR_SQL_NOTICE: gpg_err_code_t = 1527;
+pub const GPG_ERR_SQL_WARNING: gpg_err_code_t = 1528;
+pub const GPG_ERR_SQL_ROW: gpg_err_code_t = 1600;
+pub const GPG_ERR_SQL_DONE: gpg_err_code_t = 1601;
 pub const GPG_ERR_MISSING_ERRNO: gpg_err_code_t = 16381;
 pub const GPG_ERR_UNKNOWN_ERRNO: gpg_err_code_t = 16382;
 pub const GPG_ERR_EOF: gpg_err_code_t = 16383;
